from .fields import CharIDField

__all__ = ["CharIDField"]

__title__ = "django-charid-field"
__version__ = "0.2.2"
__author__ = "YunoJuno"
__license__ = "MIT License"
__copyright__ = "Copyright YunoJuno"

VERSION = __version__
